/* call.cpp */

#ifdef __cplusplus
extern "C" {
#endif

bool_t	call_game_thread_create( void *(*func)( void * ) );
bool_t	call_game_thread_exit(
	void *(*func)( void * ), long code
);
void	call_gui_map_cont_exec_set( bool_t flagExec );
void	call_gui_menu_draw( draw_menu_t *data );
void	call_gui_menu_wipe( void );
void	call_set_mouse_dflt_menu( long sel_n );
void	call_gui_message_set_flag_more( bool_t flag );
void	call_gui_message_draw( void );
void	call_gui_num_draw( long *n, long min, long max, long figure );
void	call_gui_num_wipe( void );
void	call_gui_input_string_draw(
	const char *ttl, const char *str, long len
);
void	call_gui_input_string_wipe( void );
void	set_str_dir_sel_graph( char *dir );
bool_t	call_sel_conf_eval_block_begin( void );
bool_t	call_sel_conf_eval_block_end( void );
bool_t	call_sel_conf_eval_set_num( long token, long n );
bool_t	call_sel_conf_eval_set_str( long token, char *str );
void	call_pcg_dun_reset( void );
void	call_pcg_dun_draw_turn( void );
void	call_pcg_dun_redraw( bool_t flgForce );
void	call_pcg_dun_draw(
	long map_x, long map_y,
	long map_w, long map_h,
	bool_t flagForce
);
void	call_pcg_dun_scroll( long map_x, long map_y );
long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool_t flagPre );
long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool_t flagPre );
long	call_pcg_dun_get_chr_draw_top( chr_t *chr, bool_t flagPre );
long	call_pcg_dun_get_chr_draw_bottom( chr_t *chr, bool_t flagPre );
bool_t	call_pcg_dun_clip_win( long mapX, long mapY );
bool_t	call_pcg_dun_clip_win_x( long mapX );
bool_t	call_pcg_dun_clip_win_y( long mapY );
void	call_gui_stat_redraw( void );
void	call_gui_stat_draw( long n );
long	call_key_get_char( void );

#ifdef __cplusplus
}
#endif
